
Possible attackers of the application must be documented
-------

**Description:**

Activity logs of the hackers session is very valuable information and is very helpful 
when investigating a hack on an application.


**Solution:**

The possible attackers needs to be monitored as much as possible. This information is 
crucial for forensics and law enforcements. 

Recommended knowlege-base items:

- Audit logs
- User credentials in audit logs
- Log injection
- Repudiation attacks
- Logging guidelinges
- Logging is performed before executing the transaction


